@@ -70,7 +70,7 @@ class logger:
             self.log_file.setFormatter(log_format)
             coloredlogs.install(level=logging.INFO, logger=self.logger, fmt=self.indent + '%(message)s') # Reset to default log format
 
-        log_file = open(self.log_filepath, 'r+').read()
+        log_file = open(self.log_filepath, 'r+', encoding='utf-8', errors='ignore').read()
         number_of_lines = len(log_file.splitlines())
         if number_of_lines > self.max_lines:
             self.logger.info('Resetting log file')
